
// Dummy CGPath.swift written by fuku@rouge.gr.jp

import Foundation

public
struct Pointee {

    public enum elementType {
        case moveToPoint
        case addLineToPoint
        case closeSubpath
    }

    public var type:elementType
    var points:[CGPoint]

    init() {
        self.type = elementType.moveToPoint
        self.points = []
    }

    init(to:[CGPoint],type:elementType) {
        self.type = type
        self.points = []
        for cgp in to {
            self.points.append(cgp)
        }
    }
}

public
struct ElementPointer {

    public var pointee:Pointee

    init(to:[CGPoint],type:Pointee.elementType) {
        pointee = Pointee(to:to,type:type)
    }
}

public
struct CGPath {

    var eps:[ElementPointer]

    init() {
        eps = []
    }

    public mutating func move(to:CGPoint) {
        let ep:ElementPointer = ElementPointer(to:[to],type: Pointee.elementType.moveToPoint)
        eps.append(ep)
    }

    public mutating func addLine(to:CGPoint) {
        let ep:ElementPointer = ElementPointer(to:[to],type:Pointee.elementType.addLineToPoint)
        eps.append(ep)
    }

    public mutating func closeSubpath(to:CGPoint) {
        let ep:ElementPointer = ElementPointer(to:[to],type:Pointee.elementType.closeSubpath)
        eps.append(ep)
    }

    public func applyWithBlock(_ block:(ElementPointer) -> Void) {
        for ep in eps {
            block(ep)
        }
    }
}

